#
# spec file for package python-shodan
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{!?license: %global license %doc}
Name:           python-shodan
Version:        1.10.4
Release:        3.1
Summary:        Python library and command-line utility for Shodan
License:        MIT
Group:          Development/Languages/Python
Url:            http://github.com/achillean/shodan-python/
Source:         https://files.pythonhosted.org/packages/source/s/shodan/shodan-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
Requires:       python-XlsxWriter
Requires:       python-click
Requires:       python-click-plugins
Requires:       python-colorama
Requires:       python-requests >= 2.2.1
Recommends:     python-curses
Suggests:       %{name}-doc
BuildArch:      noarch

%python_subpackages

%package -n %{name}-doc
Summary:        Documentation files for %name
Group:          Documentation/HTML
Provides:       %{python_module shodan-doc = %{version}}

%description
Shodan is a search engine for Internet-connected devices. Google lets you search for websites, Shodan lets you search for devices. This library provides developers easy access to all of the data stored in Shodan in order to automate tasks and integrate into existing tools.

%description -n %{name}-doc
HTML documentation on the API and examples for %name.

%prep
%setup -q -n shodan-%{version}
sed -i '1s/^#!.*//' shodan/cli/worldmap.py

%build
%python_build
pushd docs
make html
rm -r _build/html/.buildinfo _build/html/_sources/
make man
popd

%install
%python_install
install -Dm 644 docs/_build/man/shodan-python.1 %{buildroot}%{_mandir}/man1/shodan.1
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Tests need network access, skip them

%files %{python_files}
%defattr(-,root,root,-)
%doc AUTHORS README.rst
%%license LICENSE
%python3_only %{_bindir}/shodan
%{python_sitelib}/*
%python3_only %{_mandir}/man1/shodan.1%{ext_man}

%files -n %{name}-doc
%doc docs/_build/html

%changelog
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Sun Oct 14 2018 sebix+novell.com@sebix.at
- update to version 1.10.4:
  * Fix a bug when showing old banner records that don't have the "transport" property
* Sat Sep 22 2018 sebix+novell.com@sebix.at
- update to version 1.10.3:
  * Change bare 'except:' statements to 'except Exception:' or more specific ones
  * remove unused imports
  * Convert line endings of `shodan/client.py` and `tests/test_shodan.py` to unix
  * List file types in **shodan convert** (#80)
* Mon Sep 17 2018 sebix+novell.com@sebix.at
- update to version 1.10.2
  * Fix **shodan stats** formatting exception when faceting on **port**
- update to version 1.10.1:
  * Support PUT requests in the API request helper method
* Sun Sep  2 2018 sebix+novell.com@sebix.at
- update to version 1.10.0:
  * New command **shodan org**: manage enterprise access to Shodan for your team
  * Improved unicode handling (#78)
  * Remove deprecated API wrapper for shodanhq.com/api
* Sun Aug 26 2018 sebix+novell.com@sebix.at
- update to version 1.9.1:
  * The CHANGELOG is now part of the packages.
  * Improved unicode handling in Python2 (#78)
  * Add `tsv` output format for **shodan host** (#65)
  * Show user-friendly error messages when running **shodan radar** without permission or in a window that's too small (#74)
  * Improved exception handling to improve debugging **shodan init** (#77)
* Wed Aug  1 2018 sebix+novell.com@sebix.at
- update to version 1.9.0:
  * New optional parameter proxies for all interfaces to specify a proxy array for the requests library (#72)
- update to version 1.8.1:
  * Fixed bug that prevented shodan scan submit from finishing (#70)
* Thu May 31 2018 sebix+novell.com@sebix.at
- update to version 1.8.0:
  * Shodan CLI now installs properly on Windows (#66)
  * Improved output of "shodan host" (#64, #67)
  * Fixed bug that prevented an open port from being shown in "shodan host" (#63)
  * No longer show an empty page if "shodan search" didn't return results (#62)
  * Updated docs to make them Python3 compatible
* Sun Dec 10 2017 sebix+novell.com@sebix.at
- update to version 1.7.7
  * Added "shodan data download" command to help download bulk data files
* Tue Dec  5 2017 sebix+novell.com@sebix.at
- update to version 1.7.6:
  * addes "shodan radar" command
* Mon Sep  4 2017 sebix+novell.com@sebix.at
- upgrade to version 1.7.5
* Thu Aug  3 2017 sebix+novell.com@sebix.at
- fix build for leap
* Wed Jul 19 2017 sebix+novell.com@sebix.at
- initial version
